Opaque reference to a running SmolNet stack bundle.
The reference deliberately hides the processes which implement the bundle.
Use the functions on SmolNet rather than depending on its fields.
Opaque reference to a running SmolNet stack bundle.
The reference deliberately hides the processes which implement the bundle.
Use the functions on SmolNet rather than depending on its fields.